pyxmpp.sasl

Package pyxmpp :: Package sasl |
[hide private]

# Package sasl

source code

SASL authentication implementaion for PyXMPP.

Normative reference:
  - RFC 2222

Submodules | [hide private]
pyxmpp.sasl.core: Base classes for PyXMPP SASL implementation. pyxmpp.sasl.digest_md5: DIGEST-MD5 authentication mechanism for PyXMPP SASL implementation. pyxmpp.sasl.gssapi: GSSAPI authentication mechanism for PyXMPP SASL implementation. pyxmpp.sasl.plain: PLAIN authentication mechanism for PyXMPP SASL implementation.

Functions | [hide private]
sasl.core.ClientAuthenticator |
client_authenticator_factory(mechanism, password_manager) Create a client authenticator object for given SASL mechanism and password manager. | source code
sasl.core.ServerAuthenticator |
server_authenticator_factory(mechanism, password_manager) Create a server authenticator object for given SASL mechanism and password manager. | source code

Variables | [hide private]
| __revision__ = ``'``$Id: __init__.py 714 2010-04-05 10:20:10Z jajc``...``
| safe_mechanisms_dict = `{"DIGEST-MD5":(DigestMD5ClientAuthentic`...``
| unsafe_mechanisms_dict = `{"PLAIN":(PlainClientAuthenticator, P`...``
| all_mechanisms_dict = `safe_mechanisms_dict.copy()`
| safe_mechanisms = ``[``'``DIGEST-MD5``'``]``
| unsafe_mechanisms = ``[``'``PLAIN``'``]``
| all_mechanisms = ``[``'``DIGEST-MD5``'``,` `'``PLAIN``'``]``
| __package__ = ``'``pyxmpp.sasl``'``

Imports: random, Reply, Response, Challenge, Success, Failure, PasswordManager, PlainClientAuthenticator, PlainServerAuthenticator, DigestMD5ClientAuthenticator, DigestMD5ServerAuthenticator, GSSAPIClientAuthenticator, core, digest_md5, plain

Function Details | [hide private]

### client_authenticator_factory(mechanism, password_manager) | source code
Create a client authenticator object for given SASL mechanism and password manager. Parameters: `mechanism` (`str`) - name of the SASL mechanism ("PLAIN", "DIGEST-MD5" or "GSSAPI"). `password_manager` (PasswordManager) - name of the password manager object providing authentication credentials. Returns: sasl.core.ClientAuthenticator new authenticator.

### server_authenticator_factory(mechanism, password_manager) | source code
Create a server authenticator object for given SASL mechanism and password manager. Parameters: `mechanism` (`str`) - name of the SASL mechanism ("PLAIN", "DIGEST-MD5" or "GSSAPI"). `password_manager` (PasswordManager) - name of the password manager object to be used for authentication credentials verification. Returns: sasl.core.ServerAuthenticator new authenticator.

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: __init__.py 714 2010-04-05 10:20:10Z jajcus $'

  ### safe_mechanisms_dict Value:
      {"DIGEST-MD5":(DigestMD5ClientAuthenticator, DigestMD5ServerAuthentica
      tor)}

  ### unsafe_mechanisms_dict Value:
      {"PLAIN":(PlainClientAuthenticator, PlainServerAuthenticator)}